Adaptors
********

.. autoclass:: Dpowers.Adaptor
    :inherited-members:
    :special-members: __init__


keyb (KeyboardAdaptor)
______________________

.. adaptor:: Dpowers.KeyboardAdaptor



mouse (MouseAdaptor)
____________________

.. adaptor:: Dpowers.MouseAdaptor



clip (ClipboardAdaptor)
_______________________


.. adaptor:: Dpowers.ClipboardAdaptor



ntfy (NotificationAdaptor)
__________________________

.. adaptor:: Dpowers.NotificationAdaptor



dlg (DialogAdaptor)
___________________


.. adaptor:: Dpowers.DialogAdaptor



hook (HookAdaptor)
__________________

.. adaptor:: Dpowers.HookAdaptor



